<div class="content" style="background:none;overflow:hidden;" rel="nofollow">
    <a href="{{ banner.get_absolute_url }}" target="_blank">
        <img src="{{ banner.mediafile.file.url }}" alt="">
    </a>
</div>
<script>
(function() { try {
  var xhr = new XMLHttpRequest(),
    url = '{{ banner.impression_url }}?_bimp=' + Math.random();
  if (url) {
    xhr.open('GET', url);
    xhr.send(null);
  }
} catch(e) {}; })();
</script>
